@@ -31,6 +31,11 @@ impl<const L: usize> String<L> {
         &self
     }
 
+    /// Turns the `String` into its underlying bytes.
+    pub fn into_bytes(self) -> [u8; L] {
+        self.0
+    }
+
     /// Returns whether all bytes in the `String` are empty.
     pub fn is_empty(&self) -> bool {
         self.0.iter().all(|&x| x == b' ')
